<?php

namespace HCM\FPA\Controllers;

use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use HCM\FPA\Services\RelatCustomEventoService;
use HCM\Util\HCMParameters;
use HCM\Util\Util;

class RubricasIncideController extends Crud {

    protected $eventoService;
    protected $dataSourceName = 'getEvento';
    protected $parameterBagColumns = array('NRORG', 'NRORG_PADRAO','DTMESCOMPETENC');

    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, HCMParameters $hcmParameters, RelatCustomEventoService $relatCustomEventoService){
        $this->parameterBag = $parameterBag;
        $this->hcmParameters = $hcmParameters;
        $this->relatCustomEventoService = $relatCustomEventoService;
        parent::__construct($dataSourceManager);
    }

    
    public function getParametrizacaoEsocialIncideEvento(DTO\Request\Filter $request, DTO\Response $response){
        try{
           set_time_limit(0); 
           $filters = Util::removerCaracterePorcentagemString($request->getFilterCriteria()->getConditions());
           $parameters = array();
           foreach ($filters as $position => $filter) {
                unset($filter['operator']);
                foreach ($filter as $key => $value) {
                    if ($key == 'columnName') {
                        $parameters[$value] = $filter['value'];
                    }
                }
            }
            Util::getValueInFilterDataSourceByName($filters, array('P_NRORG', 'P_DTMESCOMPETENC', 'P_NRORG_PADRAO', 'P_NREVENTOM', 'NREVENTOM_LIST', 'NRTIPOMOVIMENT_LIST'), true);
            $conditions = Util::createQueryFiltered($filters);
            $result = $this->relatCustomEventoService->getParametrizacaoNrtipoincideEsocial($parameters, $conditions);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getParametrizacaoEsocialIncideEvento', $result));
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }   
    }
    
    protected function processConditionValue($condition) {
        return $condition['value'];
    }
    
    protected function populateParameterBag(FilterCriteria $filterCriteria) {

        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }
        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );

        return $newFilterCriteria;
    }
    
}