<?php
namespace HCM\Geral\Repository\Esocial;

use Doctrine\DBAL\Connection;
use Doctrine\ORM\EntityManager;
use HCM\Util\HCMParameters;

class S1070Repository {

    protected  $connection;

    public function __construct(EntityManager $entityManager, HCMParameters $hcmParameters) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
    }
    
    public function getItensParaEnvioS1070($params) {
        try {
            $sql = <<<SQL
SELECT PR.NRPROCESSADMJUD as NRCHAVE,
       '' as NRTABELA,
       DECODE(ENV.ENVIOS,NULL,'I','A') as IDOPERACAO,
       NVL(PR.DTESOCIAL, PR.DTINIVIGENCIA) AS DTMESCOMPETENC
  FROM GPE_PROCESSADMJUD PR
  /*QUERY PARA VERIFICAR SE É INCLUSÃO OU ALTERAÇÃO DO REGISTRO*/
  LEFT JOIN (SELECT EC.NRORG, EC.NRCHAVE, COUNT(*) AS ENVIOS
               FROM ESO_ENVIOCADASTROS EC
               JOIN ESO_EVENTO EV ON EV.NREVENTO = EC.NREVENTO
                                 AND EV.NMEVENTO = 'S-1070'
              WHERE EC.NRORG = :P_NRORG
                AND (EC.IDSTATUS = 'C' OR EC.IDSTATUS = 'A') /*QUE ESTIVER CONCLUIDO*/
                AND EC.IDATIVO = 'S' /*QUE ESTIVER ATIVO*/
                AND EC.IDOPERACAO <> 'E' /*QUE NAO TENHA EVENTO DE EXCLUSAO*/
                AND EC.NRENVIOEXCL IS NULL /*QUE NAO TENHA EVENTO DE EXCLUSAO*/
                AND EC.NRESTRUTURAM = :P_NRESTRUTURAM
                AND EC.NRTPAMBIENTE = :P_NRTPAMBIENTE
              GROUP BY EC.NRORG, EC.NRCHAVE) ENV ON ENV.NRCHAVE = PR.NRPROCESSADMJUD
 WHERE PR.NRORG = :P_NRORG
   AND PR.DTINIVIGENCIA <= :P_DTMESCOMPETENC
   AND (PR.DTFIMVIGENCIA IS NULL OR PR.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
   AND PR.NRESTRUTURAM = :P_NRESTRUTURAM
 ORDER BY 1
SQL;
            $params = array(
                "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
                "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
                "P_NRESTRUTURAM" => isset($params['NRESTRUTURAM']) ? $params['NRESTRUTURAM'] : null,
                "P_NRTPAMBIENTE" => isset($params['NRTPAMBIENTE']) ? $params['NRTPAMBIENTE'] : null,
            );
            return $this->connection->fetchAll($sql, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function getDadosS1070($params) {
        try {
            $dados = $this->getDadosPrincipais($params['NRENVIO'], $params['NRCHAVE'],  $params['NRESTRUTURAM'],  $params['NRTPAMBIENTE']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }

    public function getDadosPrincipais($nrenvio, $nrchave, $nrestruturam, $nrtpambiente) {
        $sql = <<<SQL
SELECT PR.NRPROCESSADMJUD CHAVE,
       'ID'||DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','')||RPAD(CASE WHEN PAR.CDTIPOINSCRICAO = 'CPF' OR EMH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END,14,'0')||TO_CHAR(SYSDATE, 'YYYYMMDDHH24MISS')||SUBSTR('00000'||:P_NRENVIO,-5,100) id,
       --ideEmpregador
       DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','') tpInsc,
       CASE WHEN PAR.CDTIPOINSCRICAO = 'CPF' OR EMH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END nrInsc,
       --ideProcesso
       PR.NRTPPROCESSADJU tpProc,
       REPLACE(REPLACE(PR.CDPROCESSADMJUD,'.',''),'-','') nrProc,
       --idePeriodo
       TO_CHAR(GREATEST(EMP.DTINIVIGENCIA,PR.DTINIVIGENCIA,TO_DATE(DECODE(:P_NRTPAMBIENTE, 1, DECODE(EMP.NRGRUPOESOCIAL, 3, :P_INIVALIDADEAMBNS, :P_INIVALIDADEAMBP), 2, :P_INIVALIDADEAMBPR))),'YYYY-MM') iniValid,
       TO_CHAR(PR.DTFIMVIGENCIA, 'YYYY-MM') fimValid,
       --dadosProc
       DECODE(PN.NRINSCRICAOPARC,EH.CDCNPJESTRUT,'1','2') indAutoria,
       MA.CDESOCIAL indMatProc,
       --dadosProcJud
       PR.SGUFVARAPROADJU ufVara,
       MU.CDMUNICIBGE codMunic,
       PR.CDVARAPROCEADJU idVara,
       --infoSusp :
       PR.NRORG, PR.NRPROCESSADMJUD
  FROM GPE_PROCESSADMJUD PR
  JOIN ESTRUTURAH EH ON EH.NRORG = PR.NRORG
                    AND EH.NRESTRUTURAM = PR.NRESTRUTURAM
                    AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                                WHERE DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                  AND NRESTRUTURAM = EH.NRESTRUTURAM
                                                  AND NRORG = EH.NRORG)
  /*Materia*/
  LEFT JOIN GPE_MATEPROCADJU MA ON MA.NRMATERPROCADJU = PR.NRMATERPROCADJU
  /*Autoria*/
  LEFT JOIN PARCNEGOCIO PN ON PN.NRORG = PR.NRPARCNEGOCIO
                     AND PN.NRPARCNEGOCIO = PR.NRPARCNEGOCIO
  /*Vara*/
  LEFT JOIN MUNICIPIO MU ON MU.CDMUNICIPIO = PR.CDMUNIVARPRADJU
                        AND (MU.NRORG = PR.NRORG OR MU.NRORG = 0)
  /*Empregador*/
  JOIN ESTRUTURAM EMP ON EMP.NRORG = :P_NRORG
                     AND EMP.NRESTRUTURAM = :P_NRESTRUTURAM
  JOIN ESTRUTURAH EMH ON EMH.NRORG = EMP.NRORG
                     AND EMH.NRESTRUTURAM = EMP.NRESTRUTURAM
                     AND EMH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                                WHERE DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                  AND NRESTRUTURAM = EMH.NRESTRUTURAM
                                                  AND NRORG = EMH.NRORG)
  JOIN PARCNEGOCIO PAR ON PAR.NRPARCNEGOCIO = EMH.NRPARCNEGOCIO
                      AND PAR.NRORG = EMH.NRORG
 WHERE PR.NRORG = :P_NRORG
   AND PR.NRPROCESSADMJUD = :P_NRCHAVE
SQL;
        $params = array(
            "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRTPAMBIENTE" => $nrtpambiente,
            "P_INIVALIDADEAMBPR" => $this->hcmParameters->getEsoIniValidCadIniProdRest(),
            "P_INIVALIDADEAMBP" => $this->hcmParameters->getEsoIniValidCadIniProducao(),
            "P_INIVALIDADEAMBNS" => $this->hcmParameters->getEsoIniValidCadIniNacioSimples(),
            "P_NRENVIO" => $nrenvio,
            "P_NRCHAVE" => $nrchave,
            "P_NRESTRUTURAM" => $nrestruturam,
        );
        return $this->connection->fetchAssoc($sql, $params);
    
    }
    
    public function getDadosS1070infoSusp($params){
        try{
            $params = $this->getDadosinfoSusp($params['NRORG'], $params['NRPROCESSADMJUD']);
            return $params;
        }catch(\Exception $e){
            throw $e;
        }
    }
    
    
    public function getDadosinfoSusp($nrorg, $nrprocessadmjud) {
        $sql = <<<SQL
SELECT IP.NRITEMPROCADMJUD codSusp,
       SE.CDESOCIAL indSusp,
       TO_CHAR(IP.DTITEMPROCADMJUD, 'YYYY-MM-DD') dtDecisao,
       IP.IDDEPOMONTITPROC indDeposito
  FROM GPE_ITEMPROCADMJUD IP
  LEFT JOIN GPE_SUSPEXIGITPROC SE ON SE.NRSUSPEXIGITPROC = IP.NRSUSPEXIGITPROC
 WHERE IP.NRORG = :P_NRORG
   AND IP.NRPROCESSADMJUD = :P_NRPROCESSADMJUD
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_NRPROCESSADMJUD" => $nrprocessadmjud
        );
        return $this->connection->fetchAll($sql, $params);
    }


    
}