<?php
namespace HCM\Geral\Services;

use Doctrine\ORM\EntityManager;
use HCM\Util\DateUtil;
use HCM\Util\HCMParameters;
use HCM\Util\Messages;
use HCM\Util\Repositories;

class EsoSimplificadoService {
    
    public function __construct(EntityManager $entityManager, HCMParameters $hcmParameters) {
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
        
        $this->eSocialRepository = new \HCM\Geral\Repository\ESocialRepository($this->entityManager->getConnection(), $this->entityManager, $this->hcmParameters);
    }

    public function getItensParaEnvioEvento($nmevento, $idgrupo, $params = array(), $jenkins = false) {
        try {
            $repository = $this->getRepository(str_replace('-','',$nmevento));
            $method = 'getItensParaEnvio' . str_replace('-','',$nmevento);
            
            if (method_exists($repository, $method)) {
                $itens = array();
                
                if ($nmevento != 'S-1000' && $nmevento != 'S-1010') {
                    $estruturas = $this->entityManager->getRepository(Repositories::ESTRUTURAH)->retornaEstruturasPorRaizCnpj(
                        $this->hcmParameters->getNrorgTrabalho(), $params['CDCNPJEMPREGADOR'], $this->hcmParameters->getTipoEstruturaLegalOrg(), $this->hcmParameters->getDtCompetencia()
                    );
                } else {
                    $estruturas = null;
                }
                
                if (empty($estruturas) || !$estruturas) {
                    $itens = $repository->$method($params);
                } else {
                    // Alteração para fazer a inserção para a matriz e suas filiais conforme o cnpj da estrutura posicionada
                    $nrestruturam = $params['NRESTRUTURAM']; // Gambiarra para salvar o número da estrutura matriz e inserir os envios com esse nrestruturam
                    foreach ($estruturas as $estrutura) {
                        $params['NRESTRUTURAM'] = $estrutura->getNrestruturam();
                        $itensEstrut = $repository->$method($params);
                        $itens = array_merge($itens, $itensEstrut);
                    }
                    $params['NRESTRUTURAM'] = $nrestruturam;
                }
                
                return $itens;
            } else {
                if(!$jenkins){
                    throw new \Exception(Messages::HCM09000_ESO_CALLED_EVENTO_ERROR,Messages::ERROR_MESSAGE_CODE);
                }
            }
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    private function getRepository($nmevento) {
        $repositoryClass = "\HCM\Geral\Repository\Esocial\\" . $nmevento . "Repository";
        
        $repository = new $repositoryClass($this->entityManager, $this->hcmParameters);
        return $repository;
    }
    
    public function beforeInsertCadastro($nrorg, $nrtpambiente, $nrestruturam, $cdcnpjempregador, $dtmescompetenc, $nmevento, $nrchave, $nrtabela, $idoperacao, $jenkins = false) {
        try {
            $esoEnviocadastros = $this->entityManager->getRepository(Repositories::ESO_ENVIOCADASTROS)->getEnviosCadastrosEvento(
                $this->hcmParameters->getNrorgTrabalho(), $nmevento, $nrestruturam, $nrtpambiente, 'S', $nrchave, null, [$idoperacao, 'I', 'A']
            );
            $esoCadastro = $this->entityManager->getRepository(Repositories::ESO_CADASTRO)->getEnviosEvento(
                $this->hcmParameters->getNrorgTrabalho(), $nmevento, $nrestruturam, $nrtpambiente, 'S', $nrchave, $nrtabela, [$idoperacao, 'I', 'A'], 'N'
            );
            $envios = array_merge($esoEnviocadastros, $esoCadastro);
            
            if (!empty($envios)) {
                foreach ($envios as $envio) {
                    $dtCompetencia = DateUtil::getDataDeString($dtmescompetenc, DateUtil::FORMATO_BRASILEIRO_DATAHORA);
                    // Valida se já existe o evento com a mesma chave, mesma operação e mesma competência ou competência maior
                    if (!DateUtil::comparaDatas($dtCompetencia,$envio->getDtmescompetenc(),DateUtil::DEPOIS)) {
                        if($jenkins){
                            return true;
                        }else{
                            throw new \Exception(Messages::HCM09000_ESO_UNIQUE_ENVIO_ERROR,Messages::ALERT_MESSAGE_CODE);
                        }
                    } else {
                        // Se não existir verifica se existe outro com competencia anterior e exlui para não gerar dois envios para o mesmo histórico
                        if ($envio->getDtmescompetenc() < $dtCompetencia) {
                            // Se status pendente, com erro de envio ou com erro de processamento inativa o envio para não perder o registro de tentativa de envio protocolo/recibo
                            if ($envio->getIdstatus() == 'P' || $envio->getIdstatus() == 'E' || $envio->getIdstatus() == 'R') {
                                $envio->setIdativo('N');
                                $envio->setDtultatu(DateUtil::getDataAtual());
                                $envio->setCdoperultatu($this->hcmParameters->getCdoperador());
                                $envio->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());
                                $this->entityManager->persist($envio);
                                $this->entityManager->flush();
                            }
                        }
                    }
                }
            }
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function beforeInsertNaoPeriodico($nrorg, $nrtpambiente, $nrestruturam, $cdcnpjempregador, $nrvinculom, $dtmescompetenc, $nmevento, $nrchave, $nrtabela, $idoperacao, $jenkins = false) {
        try {
            $dtCompetencia = DateUtil::getDataDeString($dtmescompetenc, DateUtil::FORMATO_BRASILEIRO_DATAHORA);
            
            //Verifica se tem envio de admissão para o vínculo nos no esocial simplificado
            $enviosAdmissao = $this->entityManager->getRepository(Repositories::ESO_NAOPERIODICO)->getEnvioAdmissaoVinculo($nrorg, $nrtpambiente, $cdcnpjempregador, $nrvinculom, $dtCompetencia);
            if (!$enviosAdmissao) {
                //Verifica se tem envio de admissão para o vínculo nos na versão antiga
                $enviosAdmissao = $this->entityManager->getRepository(Repositories::ESO_ENVIOCADASTROS)->getEnvioAdmissaoVinculo($nrorg, $nrtpambiente, $cdcnpjempregador, $nrvinculom, $dtCompetencia);
            }
            
            if (($nmevento == "S-2190" || $nmevento == "S-2200" || $nmevento == "S-2300") && !empty($enviosAdmissao)) {
                throw new \Exception("Vínculo ".$nrvinculom." já possui evento de admissão",Messages::ALERT_MESSAGE_CODE);
            }
            
            if ($nmevento != "S-2190" && $nmevento != "S-2200" && $nmevento != "S-2300" && empty($enviosAdmissao)) {
                throw new \Exception("Não foi encontrado evento de admissão para o vínculo ".$nrvinculom,Messages::ALERT_MESSAGE_CODE);
            }
            
            //Verifica se tem envio de rescisão para o vínculo nos no esocial simplificado
            $enviosRescisao = $this->entityManager->getRepository(Repositories::ESO_NAOPERIODICO)->getEnvioRescisaoVinculo($nrorg, $nrtpambiente, $cdcnpjempregador, $nrvinculom, $dtCompetencia);
            if (!$enviosRescisao) {
                //Verifica se tem envio de rescisão para o vínculo nos na versão antiga
                $enviosRescisao = $this->entityManager->getRepository(Repositories::ESO_ENVIOCADASTROS)->getEnvioRescisaoVinculo($nrorg, $nrtpambiente, $cdcnpjempregador, $nrvinculom, $dtCompetencia);
            }
                
            if ($nmevento != "S-2299" && $nmevento != "S-2399") {
                if (!empty($enviosRescisao)) {
                    throw new \Exception("Foi encontrado evento de desligamento para o vínculo ".$nrvinculom,Messages::ALERT_MESSAGE_CODE);
                }
            }
            
            $esoEnviocadastros = $this->entityManager->getRepository(Repositories::ESO_ENVIOCADASTROS)->getEnviosCadastrosEvento(
                $this->hcmParameters->getNrorgTrabalho(), $nmevento, $nrestruturam, $nrtpambiente, 'S', $nrchave
            );
            $esoNaoperiodico = $this->entityManager->getRepository(Repositories::ESO_NAOPERIODICO)->getEnviosEvento(
                $this->hcmParameters->getNrorgTrabalho(), $nmevento, $nrestruturam, $nrtpambiente, $nrvinculom, 'S', $nrchave, $nrtabela, [$idoperacao, 'I', 'R'], 'N'
            );
            $envios = array_merge($esoEnviocadastros, $esoNaoperiodico);
            
            if (!empty($envios)) {
                foreach ($envios as $envio) {
                    if (!$envio->getNrenvioexcl()) {
                        // Valida se já existe o evento com a mesma chave, mesma operação e mesma competência ou competência maior
                        if (!DateUtil::comparaDatas($dtCompetencia,$envio->getDtmescompetenc(),DateUtil::DEPOIS)) {
                            if($jenkins){
                                return true;
                            }else{
                                throw new \Exception(Messages::HCM09000_ESO_UNIQUE_ENVIO_ERROR,Messages::ALERT_MESSAGE_CODE);
                            }
                        } else {
                            // Se não existir verifica se existe outro com competencia anterior e exlui para não gerar dois envios para o mesmo histórico
                            if ($envio->getDtmescompetenc() < $dtCompetencia && $nmevento != 'S-2230' && $nmevento != 'S-2240') {
                                // Se status pendente, com erro de envio ou com erro de processamento inativa o envio para não perder o registro de tentativa de envio protocolo/recibo
                                if ($envio->getIdstatus() == 'P' || $envio->getIdstatus() == 'E' || $envio->getIdstatus() == 'R') {
                                    $envio->setIdativo('N');
                                    $envio->setDtultatu(DateUtil::getDataAtual());
                                    $envio->setCdoperultatu($this->hcmParameters->getCdoperador());
                                    $envio->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());
                                    $this->entityManager->persist($envio);
                                    $this->entityManager->flush();
                                }
                            }
                        }
                    } else {
                        // Caso exista uma exclusão ou retificação para um evento já incluído, verifica se a exclusão/retificação está concluída para permitir incluir um novo
                        $envioexcl = $this->entityManager->getRepository(Repositories::ESO_NAOPERIODICO)->findOneBy(array('nrorg' => $envio->getNrorg(), 'nrenvio' => $envio->getNrenvioexcl()));
                        if ($envioexcl) {
                            if ($envioexcl->getIdstatus() != 'A' && $envioexcl->getIdstatus() != 'C') {
                                throw new \Exception("Existe um evento de exclusão ou retificação para o vínculo ".$nrvinculom.", porém ele não foi concluído",Messages::ALERT_MESSAGE_CODE);
                            }
                        }
                    }
                }
            }
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function beforeInsertPeriodico($nrorg, $nrtpambiente, $nrestruturam, $cdcnpjempregador, $nrpessoa, $dtmescompetenc, $nmevento, $nrchave, $nrtabela, $idoperacao, $jenkins = false) {
        try {
            $dtCompetencia = DateUtil::getDataDeString($dtmescompetenc, DateUtil::FORMATO_BRASILEIRO_DATAHORA);
            
            $eventoFechamento = $this->validaFechamentoEstrutura($this->hcmParameters->getNrorgTrabalho(), $nrestruturam, $dtCompetencia, $nrtabela);
            $eventoReabertura = $this->validaReaberturaEstrutura($this->hcmParameters->getNrorgTrabalho(), $nrestruturam, $dtCompetencia, $nrtabela);
            
            if ($nmevento == 'S-1299' && $eventoFechamento && !$eventoReabertura) {
                throw new \Exception(Messages::evaluateMessage(Messages::HCM09000_ESO_ESTRUTURA_FECHAMENTO_EXISTS_ERROR, $nrestruturam));
            }
            if ($nmevento == 'S-1298' && !$eventoFechamento) {
                throw new \Exception('Não foi encontrado o evento de fechamento para a estrutura ' . $nrestruturam);
            }
            
            if ($nmevento != 'S-1298' && $nmevento != 'S-1299') {
                $esoEnviocadastros = $this->entityManager->getRepository(Repositories::ESO_ENVIOCADASTROS)->getEnviosCadastrosCnpjEvento(
                    $this->hcmParameters->getNrorgTrabalho(), $nmevento, $cdcnpjempregador, $nrtpambiente, 'S', $nrchave, $dtmescompetenc, null, [$idoperacao]
                );
                $esoPeriodico = $this->entityManager->getRepository(Repositories::ESO_PERIODICO)->getEnviosEvento(
                    $this->hcmParameters->getNrorgTrabalho(), $nmevento, $nrestruturam, $nrtpambiente, $dtCompetencia, 'S', $nrchave, $nrtabela, [$idoperacao, 'I', 'R'], 'N'
                );
                $envios = array_merge($esoEnviocadastros, $esoPeriodico);
                
                if (!empty($envios)) {
                    if($jenkins){
                        return true;
                    }else{
                        throw new \Exception(Messages::HCM09000_ESO_UNIQUE_ENVIO_ERROR,Messages::ALERT_MESSAGE_CODE);
                    }
                }
            }
        } catch(\Exception $e) {
            throw $e;
        }
    }

    public function beforeDeleteEvento($row, $repository) {
        try {
            if (($row['NMEVENTO'] == 'S-3000' || $row['IDOPERACAO'] == 'E' || $row['IDOPERACAO'] == 'R') && ($row)) {
                $enviosOrig = $this->entityManager->getRepository($repository)->findBy(array('nrorg' => $row['NRORG'], 'nrenvioexcl' => $row['NRENVIO']));
                foreach ($enviosOrig as $envioOrig) {
                    $envioOrig->setNrenvioexcl();
                    $this->entityManager->persist($envioOrig);
                    $this->entityManager->flush();
                }
            }
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function deleteEvento($nrorg, $nrenvio, $repository){
        $evento = $this->entityManager->getRepository($repository)->findOneBy(array('nrorg' => $nrorg, 'nrenvio' => $nrenvio));
        if ($evento) {
            if ($evento->getIdstatus() == 'P' && $evento->getIdevento() == '') {
                $this->entityManager->remove($evento);
            } else {
                $evento->setIdativo('N');
                $evento->setDtultatu(DateUtil::getDataAtual());
                $evento->setCdoperultatu($this->hcmParameters->getCdoperador());
                $evento->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());
                $this->entityManager->persist($evento);
            }
            $this->entityManager->flush();
            
            return true;
        }
        
        return false;
    }

    public function vefificaEventosAfastamentoPendentes($nrorg, $nrestruturam, $nrvinculom) {
        try {
            $pendentes = $this->entityManager->getRepository(Repositories::ESO_NAOPERIODICO)->findBy(array('nrorg' => $nrorg, 'nrestruturam' => $nrestruturam, 'nrvinculom' => $nrvinculom, 'nmevento' => 'S-2230', 'idstatus' => ['P', 'E', 'M', 'R']));
            return $pendentes;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function verificaEventoDataPosterior($row){
        try{
            $nrorg = $row['NRORG'];
            $nrestruturam = $row['NRESTRUTURAM'];
            $nrvinculom = $row['NRVINCULOM'];
            $pendentes = array();
            
            $pendentes = $this->entityManager->getRepository(Repositories::ESO_NAOPERIODICO)->findBy(array('nrorg' => $nrorg, 'nrestruturam' => $nrestruturam, 'nrvinculom' => $nrvinculom, 'nmevento' => ['S-2190', 'S-2200', 'S-2205', 'S-2206', 'S-2230', 'S-2300', 'S-2399', 'S-1200'], 'idstatus' => ['C', 'A'], 'idativo' => 'S'));
            
            foreach ($pendentes as $envio){
                $dataMaior = DateUtil::retornaMaiorData($envio->getDtmescompetenc(),$row['DTMESCOMPETENC']);
                if($dataMaior == $envio->getDtmescompetenc() && !$envio->getNrenvioexcl()){
                    return true;
                }
            }
            return false;
        }catch(\Exception $e){
            throw $e;
        }
    }

    public function getNaoPeriodicosPendentes($nrorg, $dtmescompetenc, $nrvinculomlist, $nmeventolist) {
        try {
            $pendentes = $this->entityManager->getRepository(Repositories::ESO_NAOPERIODICO)->findBy(array('nrorg' => $nrorg, 'nrvinculom' => $nrvinculomlist, 'nmevento' => $nmeventolist));
            return $pendentes;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function validaFechamentoEstrutura($nrorg, $nrestruturam, $dtmescompetenc, $nrtipomoviment) {
        try {
            $nrcalculofolha = $this->hcmParameters->determinaNrCalculoFolha($nrtipomoviment);
            
            // Verifica se a estrutura possui lançamento de item de fechamento
            $lancFechamento = $this->entityManager->getRepository(Repositories::FPA_ITECALCESTRUT)->findOneBy(array(
                'nrorg' => $nrorg, 'nrestruturam' => $nrestruturam, 'dtocorrencia' => $dtmescompetenc, 'nreventom' => 3035, 'idativo' => 'S', 'nrcalculofolha' => $nrcalculofolha
            ));
            
            return is_object($lancFechamento);
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function validaReaberturaEstrutura($nrorg, $nrestruturam, $dtmescompetenc, $nrtipomoviment) {
        try {
            $nrcalculofolha = $this->hcmParameters->determinaNrCalculoFolha($nrtipomoviment);
            
            // Verifica se a estrutura possui lançamento de item de reabertura
            $lancReabertura = $this->entityManager->getRepository(Repositories::FPA_ITECALCESTRUT)->findOneBy(array(
                'nrorg' => $nrorg, 'nrestruturam' => $nrestruturam, 'dtocorrencia' => $dtmescompetenc, 'nreventom' => 3036, 'idativo' => 'S', 'nrcalculofolha' => $nrcalculofolha
            ));
            
            return is_object($lancReabertura);
        } catch(\Exception $e) {
            throw $e;
        }
    }

    /**
     * Retorna o xml de envio, retorno de envio e retorno de consulta dos eventos
     * @param $nrorg
     * @param $xmlFile
     * @param $idEvento
     * @return array
     */
    public function getXmlFiles($nrorg, $xmlFile, $idEvento, $dsDirXml, $dsDirXmlFilesPath=null) {
        try {$file = $this->hcmParameters->getFileServerDirectory() . $dsDirXml;
            error_reporting(E_ALL ^ E_WARNING);
            if (fopen($file, 'r')) {
                $xml = file_get_contents($file);
            } else {
                throw new \Exception(Messages::FILE_NOT_FOUND);
            }
            error_reporting(E_ALL ^ E_NOTICE);
            return $xml;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function setXmlFileToDataSet($xmlString) {
        try {
            $json = $this->parseXmlToJson($xmlString);
            $dataSet = $this->translateESocialJson($json);
            return $dataSet;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function parseXmlToJson($xmlFileContents) {
        try {
    		$xmlFileContents = str_replace(array("\n", "\r", "\t"), '', $xmlFileContents);
    		$xmlFileContents = trim(str_replace('"', "'", $xmlFileContents));
    		$simpleXml = simplexml_load_string($xmlFileContents);
    		$json = json_encode($simpleXml);
    		return $json;
        } catch(\Exception $e) {
            throw $e;
        }
	}
	
	public function translateESocialJson($json) {
        try {
            $rows = array();
    		$this->translateESocialTag(json_decode($json,true), null, $rows);
    		return $rows;
        } catch(\Exception $e) {
            throw $e;
        }
	}
	
	public function translateESocialTag($tag, $parent, &$rows) {
        try {
            $this->_tagsTrad = array();
            $this->_tagsOpc = array();
            $tagsTrad = $this->eSocialRepository->getTagName($this->hcmParameters->getNrorgPadrao() ? $this->hcmParameters->getNrorgPadrao() : 0);
            foreach ($tagsTrad as $tag) {
                $this->_tagsTrad[$tag['DSTAGNAME']] = $tag['DSTAGTRADUCAO'] != '' ?  $tag['DSTAGTRADUCAO'] : $tag['DSTAGNAME'];
                $cdOpcoes = $tag['DSCDOPCTAG'] ? explode(';', $tag['DSCDOPCTAG']) : null;
                $nmOpcoes = $tag['DSNMOPCTAG'] ? explode(';', $tag['DSNMOPCTAG']) : null;
                if($cdOpcoes){
                    foreach($cdOpcoes as $index => $cdOpcao){
                        $this->_tagsOpc[$tag['DSTAGNAME']][$cdOpcao] = $nmOpcoes[$index];
                    }
                }
            }
            
            $this->_tagNivel ++;
	        $id = count($rows) + 1;
    		foreach ($tag as $name => $value) {
    		    if ($name === 'Signature') {
    		        // Não traduz a assinatura do evento
    		        continue;
    		    }
    		    elseif (is_array($value)) {
    		        $rows[] = array(
    		            'ID' => $id,
    		            'PARENT' => $parent,
    		            'NAME' => (is_int($name) ? $name + 1 : (isset($this->_tagsTrad[$name]) ? $this->_tagsTrad[$name] : $name)),
    		            'VALUE' => null,
    		            '_opened' => true,
    		            'NIVEL' => $this->_tagNivel
		            );
    		        $this->translateESocialTag($value, $id, $rows);
    		        $id = count($rows) + 1;
    		    } else {
    		        $rows[] = array(
    		            'ID' => $id,
    		            'PARENT' => $parent,
    		            'NAME' => (isset($this->_tagsTrad[$name]) ? $this->_tagsTrad[$name] : $name),
    		            'VALUE' => array_key_exists($name, $this->_tagsOpc) ? $value.' - '.$this->_tagsOpc[$name][$value] : $value,
    		            '_opened' => true,
    		            'NIVEL' => $this->_tagNivel
		            );
		            $id = $id + 1;
    		    }
    		}
        } catch(\Exception $e) {
            throw $e;
        }
	}
	
	public function setEnvio2200ManualSimplificadoAdmissao($arrayEnvio, $response){
        try{
            $this->entityManager->beginTransaction();
            
            $evento2200 = $this->entityManager->getRepository(Repositories::ESO_EVENTO)->findOneBy(array('nmevento' => 'S-2200', 'dsversao' => $arrayEnvio[0]['DSVERSAO']));
            $evento2300 = $this->entityManager->getRepository(Repositories::ESO_EVENTO)->findOneBy(array('nmevento' => 'S-2300', 'dsversao' => $arrayEnvio[0]['DSVERSAO']));
            
            foreach($arrayEnvio as $row){
                $dsversao = 'S-1.0';
                $row['DSVERSAO'] = $dsversao;
                
                if($row['NREVENTO'] == 'S-2200') {
                    $envio = $this->entityManager->getRepository(Repositories::ESO_ENVIOCADASTROS)->getEnviosCadastrosEvento($this->hcmParameters->getNrorgTrabalho(), 'S-2200', $row['NRESTRUTURAM'], $row['NRTPAMBIENTE'], 'S', $row['NRCHAVE']);
                    if($envio == null){
                        $envio =  $this->entityManager->getRepository(Repositories::ESO_NAOPERIODICO)->findBy(array('nrorg' => $this->hcmParameters->getNrorgTrabalho(), 'nmevento' => 'S-2200', 'nrestruturam' => $row['NRESTRUTURAM'], 'nrtpambiente' => $row['NRTPAMBIENTE'], 'nrchave' => $row['NRCHAVE'], 'idativo' => 'S'));
                    }
                } 
                if($row['NREVENTO'] == 'S-2300'){ 
                    $envio = $this->entityManager->getRepository(Repositories::ESO_ENVIOCADASTROS)->getEnviosCadastrosEvento($this->hcmParameters->getNrorgTrabalho(), 'S-2300', $row['NRESTRUTURAM'], $row['NRTPAMBIENTE'], 'S', $row['NRCHAVE']);
                     if($envio == null){
                        $envio =  $this->entityManager->getRepository(Repositories::ESO_NAOPERIODICO)->findBy(array('nrorg' => $this->hcmParameters->getNrorgTrabalho(), 'nmevento' => 'S-2300', 'nrestruturam' => $row['NRESTRUTURAM'], 'nrtpambiente' => $row['NRTPAMBIENTE'], 'nrchave' => $row['NRCHAVE'], 'idativo' => 'S'));
                    }
                }
                if(empty($envio)){
                    $esoEnviocadastros = Repositories::ESO_NAOPERIODICO;
                    
                    $envio = new $esoEnviocadastros;
                    $nmevento = '';
                    if($row['NREVENTO'] == 'S-2200') {
                        $nmevento = 'S-2200';
                        $envio->setNmevento($nmevento);
                    } else {
                        $nmevento = 'S-2300';
                        $envio->setNmevento($nmevento);;
                    }
                    $envio->setNrestruturam($row['NRESTRUTURAM']);
                    $envio->setNrvinculom($row['NRVINCULOM']);
                    $envio->setNrchave($row['NRCHAVE']);
                    $envio->setNrtabela($row['NRTABELA']);
                    $envio->setDtmescompetenc(DateUtil::getDataDeString($row['DTMESCOMPETENC'], DateUtil::FORMATO_BRASILEIRO, true));
                    $envio->setIdoperacao($row['IDOPERACAO']);
                    $envio->setIdstatus($row['IDSTATUS']);
                    $envio->setNrtpambiente($row['NRTPAMBIENTE']);
                    $envio->setNrenvioexcl(null);
                    $envio->setDsobservacao($row['DSOBSERVACAO']);
                    $envio->setDsversao($row['DSVERSAO']);
                    $envio->setIdativo($row['IDATIVO']);
                    $envio->setNrorg($this->hcmParameters->getNrorgTrabalho());
                    $envio->setDtinclusao(DateUtil::getDataAtual());
                    $envio->setCdoperinclusao($this->hcmParameters->getCdoperador());
                    $envio->setNrorginclusao($this->hcmParameters->getNrorgTrabalho());
                 
                    $envio->setNrenvio(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'ESO_NAOPERIODICO', 1, 12, true));

                    $this->entityManager->persist($envio);
                    $this->entityManager->flush();
                }
            }
            
            $this->entityManager->commit();
        }catch(\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));	 
        }
    }

}