<?php

namespace HCM\PTO\Controllers;

use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request;
use HCM\Util\HCMParameters;
use HCM\Util\DateUtil;

class BancoHorasAdmissaoController extends Crud {

    protected $parameterBagColumns = array('P_NRORG', 'P_NRORG_PADRAO', 'P_DTMESCOMPETENC');
    protected $dataSourceName = "pto_bancoHorasAdmissao";
    protected $dataSourceNameGet = "getBancoHorasAdmissao";
    
    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, HCMParameters $hcmParameters){
        $this->parameterBag = $parameterBag;
        $this->hcmParameters   = $hcmParameters;
        parent::__construct($dataSourceManager);
    }
    
    public function getBancoHorasAdmissao(DTO\Request\Filter $request, DTO\Response $response){
        try{    
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceNameGet);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData);
            $rows = $dataSet->getRows();
    
            foreach($rows as &$row){
                $row['NRESTRUTSIND']    = isset($row['NRESTRUTSIND'])   ? explode(",", $row['NRESTRUTSIND'])    : null;
                $row['NRESTRUTLEGAL']   = isset($row['NRESTRUTLEGAL'])  ? explode(",", $row['NRESTRUTLEGAL'])   : null;
                $row['NRESTRUTGEREN']   = isset($row['NRESTRUTGEREN'])  ? explode(",", $row['NRESTRUTGEREN'])   : null;
                $row['NROCUPACAOM']     = isset($row['NROCUPACAOM'])    ? explode(",", $row['NROCUPACAOM'])   : null;
            }
             
            $response->addDataSet(new DataSet($filterData->getDataSourceName(), $rows));
        }catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function setBancoHorasAdmissao(DTO\Request\DataSet $request, DTO\Response $response){
        try{
            foreach ($request->getDataSet()->getRows() as &$row) {
                if (array_key_exists('NRBANCOHORASADM', $row)) {
                    if ($row['NRBANCOHORASADM'] === '') {
                        $row['NRBANCOHORASADM'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgPadrao(), 'PTO_BANCOHORASADMI', 1, 12, true); 
                    }
                } else {
                    $row['NRBANCOHORASADM'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgPadrao(), 'PTO_BANCOHORASADMI', 1, 12, true); 
                }
                if(is_array($row['NRESTRUTSIND'])){
                    $row['NRESTRUTSIND'] = implode(',', $row['NRESTRUTSIND']);
                }
                if(is_array($row['NRESTRUTLEGAL'])){
                   $row['NRESTRUTLEGAL'] = implode(',', $row['NRESTRUTLEGAL']);
                }  
                if(is_array($row['NRESTRUTGEREN'])){
                   $row['NRESTRUTGEREN'] = implode(',', $row['NRESTRUTGEREN']);
                } 
                if(is_array($row['NROCUPACAOM'])){
                   $row['NROCUPACAOM'] = implode(',', $row['NROCUPACAOM']);
                } 
            }
            parent::save($request, $response); 
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteBancoHorasAdmissao(DTO\Request\DataSet $request, DTO\Response $response){
        try{
            parent::delete($request, $response);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    protected function processConditionValue($condition) {
        return $condition['value'];
    }
    protected function populateParameterBag(FilterCriteria $filterCriteria) {

        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }
        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );
        return $newFilterCriteria;
    }
}